# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.aws_account import AWSAccount

    globals()["AWSAccount"] = AWSAccount


class AWSAccountListResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        lazy_import()
        return {
            "accounts": ([AWSAccount],),
        }

    attribute_map = {
        "accounts": "accounts",
    }

    def __init__(self, *args, **kwargs):
        """
        List of enabled AWS accounts.

        :param accounts: List of enabled AWS accounts.
        :type accounts: [AWSAccount], optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(AWSAccountListResponse, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
